library(ggplot2)

# Set working directory
# Please set your directory to the folder containing all_bw.csv and all_bw_iv.csv"

#############################################################################################		
############Generates Figure 2 (Panel A) - OLS###############################################
#############################################################################################

# Read data from csv
data=read.csv("all_bw.csv")

# Setting Palette colors
# The palette with grey:

cbPalette <- c("#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
# The palette with black:
cbbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")

# Start at bandwidth = .02
# Subset the data by keeping rows based on values of variable bw
data<- data[data$bw>.01, ]

#Optimal Bandwidth
#Creates variable optimal in dataset band to indicate Imbens Kalyanaraman Optimal Bandwidth AND CCT Bandwidth
data$optimal <- ifelse((data$bw==.11), c("IK Optimal"), ifelse((data$bw==.12), c("CCT Optimal"), c("Bandwidth")))

#Just in case you have a stray graphics device open
graphics.off()

# Plotting the data
# Draws the bars for cn5 and cp5 
ggstandard = ggplot(data=data, aes(x =bw, y = coeff, ymin = cn5, ymax=cp5))
  
# Printing the plot as output (note that you need X11 installed on your Mac for this)
print(ggstandard
    		  # Colors the bars
    		  + geom_linerange(data=data, aes(color=optimal), size = .6)
    		  # Draws the bars for cn10 and cp10
    		  + geom_linerange(data=data, aes(x =bw, y = coeff, ymin = cn10, ymax=cp10, color=optimal), size = .95)   
    		  # Draws the points
    		  + geom_point(data=data, aes(x = bw, y = coeff, color=optimal), size = 1.95) 
    		  + geom_hline(x = 0)
    		  # Labels x and y axis
    		  + scale_x_continuous(name="Bandwidth")
    		  + scale_y_continuous(name="Coefficient on Winner Dummy")
    		  # Sets fill colors (vs. line or outline colors)
    		  + scale_fill_manual(values=cbPalette)
    		  # Sets colors and names for the legend
    		  + scale_colour_manual(values=cbPalette, name="Optimal Bandwidth", breaks=c("IK Optimal", "CCT Optimal" , "Bandwidth" ))
    		  # Sets theme for general appearance of plot
    		  + theme_bw()
    		  # Removes legend title (which is set above in scale_colour_manual)
    		  + theme(legend.title=element_blank())
    		)

# Saving the plot
ggsave(file="figure2a.tiff",width=6, height=6)

#############################################################################################		
############Generates Figure 2 (Panel B) - 2SLS##############################################
#############################################################################################

# Read data from csv
data = read.csv("all_bw_iv.csv")
		
# Setting Palette colors
# The palette with grey:
cbPalette <- c("#999999", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
# The palette with black:
cbbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")
		
# Start at bandwidth = .02
# Subset the data by keeping rows based on values of variable bw
data<- data[data$bw>.01, ]
		
#Optimal Bandwidth
#Creates variable optimal in dataset band to indicate Imbens Kalyanaraman Optimal Bandwidth AND CCT Bandwidth
data$optimal <- ifelse((data$bw==.11), c("IK Optimal"), ifelse((data$bw==.12), c("CCT Optimal"), c("Bandwidth")))
		
#Just in case you have a stray graphics device open
graphics.off()
		
# Plotting the data
# Draws the bars for cn5 and cp5 
ggstandard = ggplot(data=data, aes(x =bw, y = coeff, ymin = cn5, ymax=cp5))
		
# Printing the plot as output (note that you need X11 installed on your Mac for this)
print(ggstandard
		      # Colors the bars
		      + geom_linerange(data=data, aes(color=optimal), size = .6)
		      # Draws the bars for cn10 and cp10
		      + geom_linerange(data=data, aes(x =bw, y = coeff, ymin = cn10, ymax=cp10, color=optimal), size = .95)   
		      # Draws the points
		      + geom_point(data=data, aes(x = bw, y = coeff, color=optimal), size = 1.95) 
		      + geom_hline(x = 0)
		      # Labels x and y axis
		      + scale_x_continuous(name="Bandwidth")
		      + scale_y_continuous(name="Coefficient on Winner Dummy")
		      # Sets fill colors (vs. line or outline colors)
		      + scale_fill_manual(values=cbPalette)
		      # Sets colors and names for the legend
		      + scale_colour_manual(values=cbPalette, name="Optimal Bandwidth", breaks=c("IK Optimal", "CCT Optimal" , "Bandwidth" ))
		      # Sets theme for general appearance of plot
		      + theme_bw()
		      # Removes legend title (which is set above in scale_colour_manual)
		      + theme(legend.title=element_blank())
		)
		
# Saving the plot
ggsave(file="figure2b.tiff",width=6, height=6)

# Closes open devices
dev.off()
