
use "data_replication_qjps.dta", clear

*This creates Figure 1

*This is just so that the dots are plotted in the mid-point of the bin range and avoid having a dot right on the discontinuity line.

gen bin_small_shift=bin_small+0.01

keep if year>=1946&year<=2007&rank<=2&elec_num_oall==1&dynastic_hg_all_win==0
egen dots=mean(post_rel_hg_all_win), by(bin_small_shift)
twoway (scatter dots bin_small_shift if win_margin_reg>=-0.30&win_margin_reg<=0.30)(lpolyci post_rel_hg_all_win win_margin_reg if win_margin_reg<0&win_margin_reg>=-0.30, ciplot(rline) acolor(gray) fcolor(none) alpattern(dash)) (lpolyci post_rel_hg_all_win win_margin_reg if win_margin_reg>=0&win_margin_reg<=0.30, ciplot(rline) acolor(gray) fcolor(none) alpattern(dash) ) , legend(off) xtitle (Win Margin in First Race) ytitle(Posterior Relative in Office) xlabel(-0.3 -0.2 -0.1 0 0.1 0.2 0.3) graphregion(color(white) lcolor(white) lwidth(thick)) xline(0, lwidth(vthin) lpattern(shortdash) lcolor(gs8)) yla(, format(%9.1f)) xla(, format(%9.1f))
graph export figure1.tif, replace

use "data_replication_qjps.dta" , clear

*For Figure 2 please use R code "code_for_figure_2.R"

*This creates Figure 3

keep if year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.3&elec_num_oall==1&dynastic_hg_all_win==0&top2==1

gen Z=win_margin_reg

DCdensity Z , breakpoint(0) generate(Xj Yj r0 fhat se_fhat)  nograph

keep Z Yj Xj r0 fhat se_fhat

gen fu=fhat+1.96*se_fhat
gen fl=fhat-1.96*se_fhat

global rvX "Xj>-.30 & Xj<.30"
global rvR "r0>-.30 & r0<.30"
global gr "gray"

local theta2: display %5.3f r(theta)
local tse: display %5.3f r(se)

twoway scatter Yj Xj if $rvX, msymbol()   color($gr) xlabel(-0.3 -0.2 -0.1 0 0.1 0.2 0.3) yla(, format(%9.1f)) xla(, format(%9.1f))     ///
	|| line fhat r0 if r0>0 & $rvR, lcolor(black) lwidth(medthick) ///
		|| line fhat r0 if r0<0 & $rvR, lcolor(black) lwidth(medthick) ///
			|| line fu r0 if r0<0 & $rvR, lwidth(vthin) lpattern(longdash) lcolor($gr) ///
				|| line fu r0 if r0>0 & $rvR, lwidth(vthin) lpattern(longdash) lcolor($gr) ///
					|| line fl r0 if r0<0 & $rvR, lwidth(vthin) lpattern(longdash) lcolor($gr) ///
						|| line fl r0 if r0>0 & $rvR, lwidth(vthin) lpattern(longdash) lcolor($gr) ///
							 legend(off) ylabel(0(1.25)2.5, nogrid) xline(0, lwidth(vthin) lpattern(shortdash) lcolor(gs8)) ///
								plotregion(lpattern(solid) lcolor(gs4)) ///
									xscale(lcolor(none)) yscale(lcolor(none)) ///
										graphregion(color(white) lcolor(white) lwidth(thick)) saving(grDCall.gph, replace) ///
												note("Discontinuity est. = `theta2', s.e. =  `tse'") ///
													xtitle("Win Margin in First Race") ytitle("Density")
														graph export figure3.tif, replace



*Table 1: Biographical Information

use "biographies.dta", clear

tab relationship if winner==1
tab relationship if winner==0  														
														
														
use "data_replication_qjps.dta" , clear

*Generate Sample Dummies (Based on Win Margin)

gen sample_base_poly=cond(year>=1946&year<=2007&rank<=2&elec_num_oall==1&dynastic_hg_all_win==0,1,0)
gen sample_base_ob=cond(year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.11&elec_num_oall==1&dynastic_hg_all_win==0,1,0)
gen sample_base_5=cond(year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.05&elec_num_oall==1&dynastic_hg_all_win==0,1,0)
gen sample_base_2=cond(year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.025&elec_num_oall==1&dynastic_hg_all_win==0,1,0)

gen sample_base_noincdyn_poly=cond(year>=1946&year<=2007&rank<=2&elec_num_oall==1&dynastic_hg_all_win==0&incumb_t2==0&numdyn_hg_all_win_t2==0,1,0)
gen sample_base_noincdyn_obnind=cond(year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.11&elec_num_oall==1&dynastic_hg_all_win==0&incumb_t2==0&numdyn_hg_all_win_t2==0,1,0)
gen sample_base_noincdyn_5=cond(year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.05&elec_num_oall==1&dynastic_hg_all_win==0&incumb_t2==0&numdyn_hg_all_win_t2==0,1,0)

gen sample_incu_poly=cond(year>=1946&year<=2007&rank<=2&incumbent==1&prev_term_inc==1&num_term==1&dynastic_hg_all_win==0,1,0)
gen sample_incu_ob=cond(year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.16&incumbent==1&prev_term_inc==1&num_term==1&dynastic_hg_all_win==0,1,0)
gen sample_incu_5=cond(year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.05&incumbent==1&prev_term_inc==1&num_term==1&dynastic_hg_all_win==0,1,0)
gen sample_incu_2=cond(year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=0.025&incumbent==1&prev_term_inc==1&num_term==1&dynastic_hg_all_win==0,1,0)

egen num_sample_base_ob=sum(sample_base_ob), by(constituency district term_pi year)
egen num_sample_base_5=sum(sample_base_5), by(constituency district term_pi year)
egen num_sample_base_poly=sum(sample_base_poly), by(constituency district term_pi year)

label var sample_base_poly "Dummy for baseline sample Polynomial"
label var sample_base_ob "Dummy for baseline sample I&K Opt. Bandwidth"
label var sample_base_5 "Dummy for baseline sample 5% Bandwidth"
label var sample_base_2 "Dummy for baseline sample 2.5% Bandwidth"
label var sample_base_noincdyn_obnind "Dummy for sample Table 7(A) - I&K Bw"
label var sample_base_noincdyn_5 "Dummy for sample Table 7(A) - 5% Bw"
label var sample_base_noincdyn_poly "Dummy for sample Table 7(A) - Poly"
label var sample_incu_poly "Dummy for incumbent sample Polynomial"
label var sample_incu_ob "Dummy for incumbent sample I&K Opt. Bandwidth"
label var sample_incu_5 "Dummy for incumbent sample 5% Bandwidth"
label var sample_incu_2 "Dummy for incumbent sample 2.5% Bandwidth"
label var num_sample_base_ob "Num. amongst top 2 in op. bwidth sample" 
label var num_sample_base_5 "Num. amongst top 2 in 5% bwidth sample" 
label var num_sample_base_poly "Num. amongst top 2 in full sample" 

*This simply computes the I&K and CCT optimal bandwidths

*Optimal bandwidth for regressions on the extensive margin in Tables 2-7
rdbwselect post_rel_hg_all_win win_margin_reg if sample_base_poly==1, all kernel(uni)

*Optimal bandwidth for regressions on the extensive margin in Table A1
rdbwselect post_rel_hg_all_win win_margin_reg if sample_incu_poly==1, all kernel(uni)

*Table 2: RD Regressions Reduced Form-Benchmark


reg post_rel_hg_all_win winner if year>=1946&year<=2007, robust cluster(candidate)
outreg2 winner using "table2.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg post_rel_hg_all_win winner i.provincelg i.term_pi if year>=1946&year<=2007, robust cluster(candidate)
outreg2 winner using "table2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
reg post_rel_hg_all_win winner win_margin_reg int_winner_wm  if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "table2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "table2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)

*Table 3: RD Regressions Reduced Form-Alternative

reg post_rel_hg_all_win winner  if sample_base_5==1, robust cluster(provincelg)
outreg2 winner using "table3.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg post_rel_hg_all_win winner  i.provincelg i.term_pi if sample_base_5==1, robust cluster(provincelg)
outreg2 winner using "table3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
reg post_rel_hg_all_win winner  if sample_base_2==1, robust cluster(provincelg)
outreg2 winner using "table3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner  i.provincelg i.term_pi if sample_base_2==1, robust cluster(provincelg)
outreg2 winner using "table3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
reg post_rel_hg_all_win winner win_margin_reg-win_margin_reg2 int_winner_wm-int_winner_wm2  if sample_base_poly==1, robust cluster(provincelg)
outreg2 winner using "table3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner win_margin_reg-win_margin_reg2 int_winner_wm-int_winner_wm2  i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg)
outreg2 winner using "table3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
reg post_rel_hg_all_win winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3  if sample_base_poly==1, robust cluster(provincelg)
outreg2 winner using "table3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3  i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg)
outreg2 winner using "table3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)


*Table 4: RD Regressions for Baseline Sample-IV

ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg int_winner_wm)  if sample_base_ob==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg int_winner_wm)  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
ivreg post_rel_hg_all_win (gov_or_house=winner)  if sample_base_5==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner)  i.provincelg i.term_pi if sample_base_5==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
ivreg post_rel_hg_all_win (gov_or_house=winner)  if sample_base_2==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt", label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner)  i.provincelg i.term_pi if sample_base_2==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg-win_margin_reg2 int_winner_wm-int_winner_wm2)  if sample_base_poly==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house =winner win_margin_reg-win_margin_reg2 int_winner_wm-int_winner_wm2)  i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3)  if sample_base_poly==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house =winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3)  i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg) first
outreg2 gov_or_house using "table4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)


*Table 5: Validity Checks


xi: reg coalition winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995, robust cluster(provincelg)
outreg2 winner using "table5.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg prev_exp winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995, robust cluster(provincelg)
outreg2 winner using "table5.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg female winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "table5.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg incumb_t2 winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "table5.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg dynastic_t2 winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "table5.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg seasoned_t2 winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "table5.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)


*Table 6: RD Regressions for Robustness I-(Adding Controls)

xi: reg post_rel_hg_all_win winner win_margin_reg int_winner_wm female par_* prev_exp coalition i.provincelg i.term_pi if sample_base_ob==1&year>=1995, robust cluster(provincelg)
outreg2 winner using "table6.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
gen sample_wcont_ob=1 if e(sample)==1
xi: reg post_rel_hg_all_win winner i.provincelg i.term_pi female par_* prev_exp coalition if sample_base_5==1&year>=1995, robust cluster(provincelg)
outreg2 winner using "table6.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
gen sample_wcont_5=1 if e(sample)==1
xi: reg post_rel_hg_all_win winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3 i.provincelg i.term_pi female par_* prev_exp coalition if sample_base_poly==1&year>=1995, robust cluster(provincelg)
outreg2 winner using "table6.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
gen sample_wcont_poly=1 if e(sample)==1
xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg int_winner_wm) female par_* prev_exp coalition i.provincelg i.term_pi if sample_base_ob==1&year>=1995, robust cluster(provincelg)
outreg2 gov_or_house using "table6.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner)female par_* prev_exp coalition i.provincelg i.term_pi  if sample_base_5==1&year>=1995, robust cluster(provincelg)
outreg2 gov_or_house using "table6.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3)female par_* prev_exp coalition i.provincelg i.term_pi if sample_base_poly==1&year>=1995, robust cluster(provincelg)
outreg2 gov_or_house using "table6.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)

*Table 7: RD Regressions for Robustness II-(No-Dynastic or Incumbents)

xi: reg post_rel_hg_all_win winner win_margin_reg int_winner_wm i.provincelg i.term_pi if sample_base_noincdyn_obnind==1, robust cluster(provincelg)
outreg2 winner using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg post_rel_hg_all_win winner i.provincelg i.term_pi if sample_base_noincdyn_5==1, robust cluster(provincelg)
outreg2 winner using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3  i.provincelg i.term_pi if sample_base_noincdyn_poly==1, robust cluster(provincelg)
outreg2 winner using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)

xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg int_winner_wm) i.provincelg i.term_pi if sample_base_noincdyn_obnind==1, robust cluster(provincelg)
outreg2 gov_or_house using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner) i.provincelg i.term_pi if sample_base_noincdyn_5==1, robust cluster(provincelg)
outreg2 gov_or_house using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3) i.provincelg i.term_pi if sample_base_noincdyn_poly==1, robust cluster(provincelg)
outreg2 gov_or_house using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)

xi: reg post_rel_hg_all_win winner win_margin_reg int_winner_wm i.provincelg i.term_pi if sample_base_ob==1&num_sample_base_ob==2, robust cluster(provincelg)
outreg2 winner using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner i.provincelg i.term_pi if sample_base_5==1&num_sample_base_5==2, robust cluster(provincelg)
outreg2 winner using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3 i.provincelg i.term_pi if sample_base_poly==1&num_sample_base_poly==2, robust cluster(provincelg)
outreg2 winner using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)

xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg int_winner_wm) i.provincelg i.term_pi if sample_base_ob==1&num_sample_base_ob==2, robust cluster(provincelg)
outreg2 gov_or_house using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner) i.provincelg i.term_pi if sample_base_5==1&num_sample_base_5==2, robust cluster(provincelg)
outreg2 gov_or_house using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3) i.provincelg i.term_pi if sample_base_poly==1&num_sample_base_poly==2, robust cluster(provincelg)
outreg2 gov_or_house using "table7.txt" , label excel noaster  bdec(3) tdec(3) nocons append keep(gov_or_house)

*Table 8: Vote_Share and Dynastic Candidates and Incumbents Relatives

xi:reg vote_share dynastic_hg_all_win i.provincelg i.term_pi if year>=1946&elec_num_oall==1, robust cluster(provincelg)
outreg2 dynastic_hg_all_win using "table8.txt" , label excel noaster  bdec(3) tdec(3) replace keep(dynastic_hg_all_win)
xi:reg vote_share dynastic_hg_all_win relative_inc i.provincelg i.term_pi if year>=1946&elec_num_oall==1, robust cluster(provincelg)
outreg2 dynastic_hg_all_win relative_inc using "table8.txt" , label excel noaster  bdec(3) tdec(3) append keep(dynastic_hg_all_win relative_inc)

****************
*Appendix Tables
****************

*Table A1: Regressions for the Intensive Margin

xi: reg post_rel_hg_all_win winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_incu_ob==1, robust cluster(provincelg)
outreg2 winner using "tablea1.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg post_rel_hg_all_win winner  i.provincelg i.term_pi if sample_incu_5==1, robust cluster(provincelg)
outreg2 winner using "tablea1.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner i.provincelg i.term_pi if sample_incu_2==1, robust cluster(provincelg)
outreg2 winner using "tablea1.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)

xi: ivreg post_rel_hg_all_win (longterm=winner win_margin_reg int_winner_wm)  i.provincelg i.term_pi if sample_incu_ob==1, robust cluster(provincelg)
outreg2 longterm using "tablea1.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(longterm)
xi: ivreg post_rel_hg_all_win (longterm=winner)   i.provincelg i.term_pi if sample_incu_5==1, robust cluster(provincelg)
outreg2 longterm using "tablea1.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(longterm)
xi: ivreg post_rel_hg_all_win (longterm=winner)   i.provincelg i.term_pi if sample_incu_2==1, robust cluster(provincelg)
outreg2 longterm using "tablea1.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(longterm)


*Table A2: Validity Checks for Individual Party Groups

xi: reg par_pmp winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg par_np winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg par_npc winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg par_lp winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg par_pdp winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg par_ldp winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg par_lakas winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg par_kampi winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg par_ind winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1&year>=1995&year<=2007, robust cluster(provincelg)
outreg2 winner using "tablea2.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)

*Table A3: Table 6 Without Controls but in same constrained sample

xi: reg post_rel_hg_all_win winner win_margin_reg int_winner_wm i.provincelg i.term_pi if sample_wcont_ob==1, robust cluster(provincelg)
outreg2 winner using "tablea3.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg post_rel_hg_all_win winner i.provincelg i.term_pi if sample_wcont_5==1, robust cluster(provincelg)
outreg2 winner using "tablea3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3 i.provincelg i.term_pi if sample_wcont_poly==1, robust cluster(provincelg)
outreg2 winner using "tablea3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg int_winner_wm) i.provincelg i.term_pi if sample_wcont_ob==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner) if sample_wcont_5==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win (gov_or_house=winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3) i.provincelg i.term_pi if sample_wcont_poly==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea3.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)

*Table A4: Dependent Variable not Constrained to 20-year Window (Post Relative Ever)

xi: reg post_rel_hg_all winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "tablea4.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg post_rel_hg_all winner  i.provincelg i.term_pi if sample_base_5==1, robust cluster(provincelg)
outreg2 winner using "tablea4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all winner  i.provincelg i.term_pi if sample_base_2==1, robust cluster(provincelg)
outreg2 winner using "tablea4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3  i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg)
outreg2 winner using "tablea4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)

xi: ivreg post_rel_hg_all (gov_or_house=winner win_margin_reg int_winner_wm)  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea4.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all (gov_or_house=winner)   i.provincelg i.term_pi if sample_base_5==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea4.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)
xi: ivreg post_rel_hg_all (gov_or_house=winner)   i.provincelg i.term_pi if sample_base_2==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea4.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)
xi: ivreg post_rel_hg_all (gov_or_house=winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3 )   i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea4.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)


*Table A5: Using dummy for whether a relative ran as dependent variable

*Panel A

xi: reg post_relcan_all_win winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "tablea5_a.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg post_relcan_all_win winner  i.provincelg i.term_pi if sample_base_5==1, robust cluster(provincelg)
outreg2 winner using "tablea5_a.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_relcan_all_win winner  i.provincelg i.term_pi if sample_base_2==1, robust cluster(provincelg)
outreg2 winner using "tablea5_a.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_relcan_all_win winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3  i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg)
outreg2 winner using "tablea5_a.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)

xi: ivreg post_relcan_all_win (gov_or_house=winner win_margin_reg int_winner_wm)  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea5_a.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_relcan_all_win (gov_or_house=winner)   i.provincelg i.term_pi if sample_base_5==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea5_a.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)
xi: ivreg post_relcan_all_win (gov_or_house=winner)   i.provincelg i.term_pi if sample_base_2==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea5_a.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)
xi: ivreg post_relcan_all_win (gov_or_house=winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3 )   i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea5_a.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)

*Panel B: Baseline results controlling for whether a relative ran

xi: reg post_rel_hg_all_win post_relcan_all_win winner win_margin_reg int_winner_wm  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 winner using "tablea5_b.txt" , label excel noaster  bdec(3) tdec(3) nocons replace  keep(winner)
xi: reg post_rel_hg_all_win post_relcan_all_win winner  i.provincelg i.term_pi if sample_base_5==1, robust cluster(provincelg)
outreg2 winner using "tablea5_b.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win post_relcan_all_win winner  i.provincelg i.term_pi if sample_base_2==1, robust cluster(provincelg)
outreg2 winner using "tablea5_b.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)
xi: reg post_rel_hg_all_win post_relcan_all_win winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3  i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg)
outreg2 winner using "tablea5_b.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(winner)

xi: ivreg post_rel_hg_all_win post_relcan_all_win (gov_or_house=winner win_margin_reg int_winner_wm)  i.provincelg i.term_pi if sample_base_ob==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea5_b.txt" , label excel noaster  bdec(3) tdec(3) nocons append  keep(gov_or_house)
xi: ivreg post_rel_hg_all_win post_relcan_all_win (gov_or_house=winner)   i.provincelg i.term_pi if sample_base_5==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea5_b.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)
xi: ivreg post_rel_hg_all_win post_relcan_all_win (gov_or_house=winner)   i.provincelg i.term_pi if sample_base_2==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea5_b.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)
xi: ivreg post_rel_hg_all_win post_relcan_all_win (gov_or_house=winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3)   i.provincelg i.term_pi if sample_base_poly==1, robust cluster(provincelg)
outreg2 gov_or_house using "tablea5_b.txt" , label excel noaster  bdec(3) tdec(3) nocons append   keep(gov_or_house)


*Prepare Output Data for Coefficient Plots in Figures 2A and 2B

*OLS Regressions

******define global variables 
global d0 "winner i.provincelg i.term_pi"
global d1 "winner win_margin_reg int_winner_wm i.provincelg i.term_pi"
global d1iv "(gov_or_house=winner win_margin_reg int_winner_wm) i.provincelg i.term_pi"
global d2 "winner win_margin_reg-win_margin_reg2 int_winner_wm-int_winner_wm2 i.provincelg i.term_pi"
global d3 "winner win_margin_reg-win_margin_reg3 int_winner_wm-int_winner_wm3 i.provincelg i.term_pi"
global d4 "winner win_margin_reg-win_margin_reg4 int_winner_wm-int_winner_wm4 i.provincelg i.term_pi"
global d5 "winner win_margin_reg-win_margin_reg5 int_winner_wm-int_winner_wm5 i.provincelg i.term_pi"
 
 *****program to save coefficients
capture program drop save_coeff
program define save_coeff
	args bw RDpoly
	replace bw="`bw'" if indexnum==$counter
	replace RDpoly="`RDpoly'" if indexnum==$counter
	replace coeff=_b[winner] if indexnum==$counter
	replace se=_se[winner] if indexnum==$counter
	di "output saved"
	global counter =$counter+1
end

*****program to prepare data
capture program drop prep_data
program define prep_data

	use "data_replication_qjps.dta", clear
		
	*Variables for storing output
	g bw=""
	g RDpoly=""
	g coeff=.
	g se=.	
	g indexnum=_n
end

**********
**Run regressions 
**********
prep_data /*prep data*/
global counter=1 /*for saving output*/


foreach X of num 0.01(0.01)0.5 {
	
	*distance specs
	
		
	xi: reg post_rel_hg_all_win $d1 if year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=`X'&elec_num_oall==1&dynastic_hg_all_win==0, robust cluster(provincelg)
	save_coeff `X' d1_win
	
		
	}

drop if bw==""

*create confidence intervals
g cp5=coeff+1.96*se
g cn5=coeff-1.96*se
g cp10=coeff+1.65*se
g cn10=coeff-1.65*se

outsheet bw RDpoly coeff se cn5 cp5 cn10 cp10 using all_bw.csv, comma replace


*IV Regressions


******define global variables 

global d1 "(gov_or_house=winner win_margin_reg int_winner_wm) i.provincelg i.term_pi"
 
 *****program to save coefficients
capture program drop save_coeff
program define save_coeff
	args bw RDpoly
	replace bw="`bw'" if indexnum==$counter
	replace RDpoly="`RDpoly'" if indexnum==$counter
	replace coeff=_b[gov_or_house] if indexnum==$counter
	replace se=_se[gov_or_house] if indexnum==$counter
	di "output saved"
	global counter =$counter+1
end

*****program to prepare vhlss data
capture program drop prep_data
program define prep_data

	use "data_replication_qjps.dta", clear
		
	*Variables for storing output
	g bw=""
	g RDpoly=""
	g coeff=.
	g se=.	
	g indexnum=_n
end

**********
**Run regressions 
**********
prep_data /*prep data*/
global counter=1 /*for saving output*/


foreach X of num 0.01(0.01)0.5 {
	
	*distance specs
	
		
	xi: ivreg post_rel_hg_all_win $d1 if year>=1946&year<=2007&rank<=2&abs(win_margin_reg)<=`X'&elec_num_oall==1&dynastic_hg_all_win==0, robust cluster(provincelg)
	save_coeff `X' d1_win
		
	}

drop if bw==""

*create confidence intervals
g cp5=coeff+1.96*se
g cn5=coeff-1.96*se
g cp10=coeff+1.65*se
g cn10=coeff-1.65*se

outsheet bw RDpoly coeff se cn5 cp5 cn10 cp10 using all_bw_iv.csv, comma replace


